NAME
SVK::MimeDetect::Internal - minimalist MIME type detection
DESCRIPTION
This class performs the least amount of MIME type detection possible while still providing enough metadata for SVK to function properly. It simply assigns 'application/octet-stream' to any file that looks like binary data. It assigns 'text/plain' to everything else.
AUTHORS
Michael Hendricks <michael@ndrix.org>
COPYRIGHT
Copyright 2003-2006 by Chia-liang Kao <clkao@clkao.org>.
This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.